@@ -4,12 +4,14 @@ package Fuse::Template::App;
 
 Fuse::Template::App - Application role for fuse-template
 
+=head1 SYNOPSIS
+
+See C<bin/fuse-template> for example.
+
 =cut
 
 use Moose::Role;
 use Fuse;
-use threads;
-use threads::shared;
 
 with 'MooseX::Getopt';
 
@@ -24,7 +26,8 @@ MooseX::Getopt::OptionTypeMap->add_option_type_to_map(
 
 =head2 help
 
- $bool = $self->help;
+Provides "--help", which again prints a list of command line
+options.
 
 =cut
 
@@ -36,7 +39,7 @@ has help => (
 
 =head2 man
 
- $bool = $self->man;
+Provides "--man", which will run perldoc on L<Fuse::Template>.
 
 =cut
 
@@ -50,9 +53,7 @@ has man => (
 
 =head2 run
 
- $exit_code = $self->run;
-
-Starts L<Fuse>'s mainloop.
+Set up objects and starts the L<Fuse> mainloop.
 
 =cut
 
@@ -67,6 +68,11 @@ sub run {
         exec perldoc => grep { m[ Fuse/Template.pm$ ]x } values %INC;
     }
 
+    unless($self->mountpoint and $self->root) {
+        warn "Usage: fuse-template --help\n\n";
+        return 1;
+    }
+
     for my $method (Fuse::Template::Sys->meta->get_method_list) {
         $callbacks{$method} = sub { $self->$method(@_) };
     }
@@ -84,6 +90,11 @@ sub run {
     return 0;
 }
 
+sub _threads_enabled {
+    return 1 if(grep { $_ eq 'threads.pm' } keys %INC);
+    return 0;
+}
+
 =head1 AUTHOR
 
 See L<Fuse::Template>.
